@@ -3,6 +3,8 @@ import time
 from raise_utils.metrics.metrics import ClassificationMetrics
 from raise_utils.transform.transform import Transform
 import random
+import numpy as np
+import pandas as pd
 import string
 
 
@@ -48,10 +50,15 @@ class Experiment:
         self.data = data
 
         # Apply transforms
+        # First, preserve columns
+        columns = self.data.x_train.columns
         for t in self.transforms:
             transform = Transform(t, random=self.random)
             transform.apply(self.data)
 
+        self.data.x_train = pd.DataFrame(self.data.x_train, columns=columns)
+        self.data.x_test = pd.DataFrame(self.data.x_test, columns=columns)
+
         results = {learn.__name__: {m: [] for m in self.metrics}
                    for learn in self.learners}
 
@@ -76,7 +83,8 @@ class Experiment:
                 # Evaluate
                 metric = ClassificationMetrics(self.data.y_test, predictions)
                 if "popt20" in self.metrics:
-                    metric.add_data(self.data.get_popt_data(predictions))
+                    metric.add_data(self.data.get_popt_data(
+                        predictions))
                 metric.add_metrics(self.metrics)
                 values = metric.get_metrics()
                 for j, m in enumerate(self.metrics):
